@@ -1,6 +1,6 @@
 # JGT PDS
 #
-# Copyright 20.1.3022 Jean Guillaume Isabelle
+# Copyright 20.1.4022 Jean Guillaume Isabelle
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@ import fxcmpy as fx
 # import jgtpy.JGTIDS as ids
 from jgtpy.JGTCore import __version__
 
-from jgtpy.JGTPDS import mk_fn,mk_fullpath,getSubscribed,getPH,tryConnect
+from jgtpy.JGTPDS import mk_fn,mk_fullpath,getSubscribed,getPH,getPHByRange,tryConnect
 from jgtpy.JGTCDS import create as createCDS,startSession,stopSession,getLast,getPresentBar,getPresentBarAsList,getLastCompletedBarAsList
 # from jgtpy.JGTADS import ads_chart_pto,retrieve_n_chart as ads_retrieve_n_chart
 
